from distutils.core import setup
setup(
  name = 'betfair',
  packages = ['betfair'],
  version = '0.1',
  description = 'Betfair Next Generation asyncio API',
  author = 'Anton Zemlyanov',
  author_email = 'anton.zem@gmail.com',
  url = 'https://bitbucket.com/Algotrader/betfair.py',
  download_url = 'https://bitbucket.com/Algotrader/betfair.py',
  keywords = ['betfair', 'asyncio'],
  classifiers = [],
)
